@@ -28,26 +28,23 @@
 
 use time::{OffsetDateTime, PrimitiveDateTime, UtcOffset};
 
-pub trait Offset
-{
+pub trait Offset {
     fn to_utc(&self) -> UtcOffset;
     fn name(&self) -> &str;
+    fn is_dst(&self) -> bool;
 }
 
-pub trait TimeZone
-{
+pub trait TimeZone {
     type Offset: Offset;
     fn get_offset_utc(&self, date_time: &OffsetDateTime) -> Self::Offset;
     fn name(&self) -> &str;
 }
 
-pub trait OffsetDateTimeExt
-{
+pub trait OffsetDateTimeExt {
     fn to_timezone<T: TimeZone>(&self, tz: &T) -> OffsetDateTime;
 }
 
-pub trait PrimitiveDateTimeExt
-{
+pub trait PrimitiveDateTimeExt {
     fn assume_timezone<T: TimeZone>(&self, tz: &T) -> OffsetDateTime;
 }
 
@@ -65,24 +62,27 @@ impl OffsetDateTimeExt for OffsetDateTime {
     }
 }
 
+mod binary_search;
 mod timezone_impl;
 pub mod timezones;
-mod binary_search;
 
 #[cfg(feature = "system")]
 pub mod system;
 
+#[cfg(feature = "posix-tz")]
+pub mod posix_tz;
+
 pub use timezone_impl::Tz;
 
 #[cfg(test)]
 mod tests {
-    use time::macros::datetime;
-    use time::OffsetDateTime;
-    use crate::PrimitiveDateTimeExt;
-    use crate::OffsetDateTimeExt;
     use crate::timezones;
-    use crate::TimeZone;
     use crate::Offset;
+    use crate::OffsetDateTimeExt;
+    use crate::PrimitiveDateTimeExt;
+    use crate::TimeZone;
+    use time::macros::{datetime, offset};
+    use time::OffsetDateTime;
 
     #[test]
     fn names() {
@@ -117,4 +117,18 @@ mod tests {
         let expected = datetime!(2016-10-8 18:0:0).assume_timezone(timezones::db::europe::BERLIN);
         assert_eq!(converted, expected);
     }
+
+    #[test]
+    fn dst() {
+        let london = timezones::db::europe::LONDON;
+        let odt1 = datetime!(2021-01-01 12:0:0 UTC);
+        assert_eq!(odt1.to_timezone(london), datetime!(2021-01-01 12:0:0 +0));
+        let odt2 = datetime!(2021-07-01 12:0:0 UTC);
+        // Adding offset to datetime call causes VERY surprising result: hours randomly changes!!
+        // When using UTC followed by .to_offset no surprising result.
+        assert_eq!(
+            odt2.to_timezone(london),
+            datetime!(2021-07-01 12:0:0 UTC).to_offset(offset!(+1))
+        );
+    }
 }
